#include <zephyr.h>
#include <misc/printk.h>
#include <logging/log.h>
LOG_MODULE_REGISTER(app);
#include <string.h>
#include <lte_lc.h>

#include <modem_info.h>


#define BUF_LEN CONFIG_MODEM_INFO_BUFFER_SIZE
char buf[BUF_LEN];

void main(void)
{
	int err_code = 0;

	err_code = modem_info_init();
	if (err_code) {
		LOG_ERR("ERROR modem_info_init: %d", err_code);
		return;
	}

	err_code = modem_info_string_get(MODEM_INFO_DATE_TIME, buf);
	if (err_code < 0) {
		LOG_ERR("modem info returned for DATE_TIME %d %s", err_code, log_strdup(strerror(-err_code)));
	} else {
		LOG_INF("DATE_TIME %s", log_strdup(buf));
		memset(buf, 0, BUF_LEN);
	}

	LOG_INF("connecting to network");
	err_code = lte_lc_init_and_connect();
	if (err_code) {
		LOG_ERR("Unable to connect to the network %d", err_code);
		return;
	}

	// A dely to ensure that the modem get to sync time
	k_sleep(K_SECONDS(5));
	LOG_INF("Connected to network");

	err_code = modem_info_string_get(MODEM_INFO_DATE_TIME, buf);
	if (err_code < 0) {
		LOG_ERR("modem info returned for DATE_TIME %d %s", err_code, log_strdup(strerror(-err_code)));
	} else {
		LOG_INF("DATE_TIME %s", log_strdup(buf));
		memset(buf, 0, BUF_LEN);
	}

	err_code = modem_info_string_get(MODEM_INFO_UICC, buf);
	if (err_code < 0) {
		LOG_ERR("modem info returned for UICC %d %s", err_code, log_strdup(strerror(-err_code)));
	} else {
		LOG_INF("UICC %s", log_strdup(buf));
		memset(buf, 0, BUF_LEN);
	}

	err_code = modem_info_string_get(MODEM_INFO_UICC, buf);
	if (err_code < 0) {
		LOG_ERR("modem info returned for UICC %d %s", err_code, log_strdup(strerror(-err_code)));
	} else {
		LOG_INF("UICC %s", log_strdup(buf));
		memset(buf, 0, BUF_LEN);
	}

	u16_t uicc;
	err_code = modem_info_short_get(MODEM_INFO_UICC, &uicc);
	if (err_code < 0) {
		LOG_ERR("modem info returned for UICC %d %s", err_code, log_strdup(strerror(-err_code)));
	} else {
		LOG_INF("UICC %d", uicc);
		memset(buf, 0, BUF_LEN);
	}

    	char modem_version[MODEM_INFO_MAX_RESPONSE_SIZE] = {0};
    	modem_info_string_get(MODEM_INFO_FW_VERSION, modem_version);
	//k_sleep(K_MSEC(50));
    	LOG_INF("1 Modem Version: %s", log_strdup(modem_version));
    
    	char imei[MODEM_INFO_MAX_RESPONSE_SIZE] = {0};
    	modem_info_string_get(MODEM_INFO_IMEI, imei);
	//k_sleep(K_MSEC(50));
    	LOG_INF("2 IMEI: %s", log_strdup(imei));
	
	char modem_version_3[MODEM_INFO_MAX_RESPONSE_SIZE] = {0};
    	modem_info_string_get(MODEM_INFO_FW_VERSION, modem_version_3);
	//k_sleep(K_MSEC(50));
    	LOG_INF("3 Modem Version: %s", log_strdup(modem_version_3));

	char modem_version_2[MODEM_INFO_MAX_RESPONSE_SIZE] = {0};
    	modem_info_string_get(MODEM_INFO_FW_VERSION, modem_version_2);
	//k_sleep(K_MSEC(50));
    	LOG_INF("4 Modem Version: %s", log_strdup(modem_version_2));
}
